package
Version:
v1.3.331
Opens a new window with list of versions in this module.
Published: Jan 14, 2022
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 2
Opens a new window with list of known importers.
Documentation
¶
-
func Back(p float32, flag int) float32
-
func Bounce(p float32, flag int) float32
-
func Circ(p float32, flag int) float32
-
func Cubic(p float32, flag int) float32
-
func Elastic(p float32, flag int) float32
-
func Ex(pos float32, flag int) float32
-
func Expo(p float32, flag int) float32
-
func Linear(p float32) float32
-
func Quad(p float32, flag int) float32
-
func Quart(p float32, flag int) float32
-
func Quint(p float32, flag int) float32
-
func Sine(p float32, flag int) float32
缓动_Back, 回弹, 比较缓慢.
p: 位置, 0.0f - 1.0f.
flag: 缓动类型, Ease_Type_.
缓动_Bounce.
p: 位置, 0.0f - 1.0f.
flag: 缓动类型, Ease_Type_.
缓动_Circ, 圆环, 好比绕过一个圆环.
p: 位置, 0.0f - 1.0f.
flag: 缓动类型, Ease_Type_.
缓动_Cubic, 三次方曲线, 圆弧.
p: 位置, 0.0f - 1.0f.
flag: 缓动类型, Ease_Type_.
缓动_Elastic, 强力回弹.
p: 位置, 0.0f - 1.0f.
flag: 缓动类型, Ease_Type_.
缓动_扩展, 全部缓动类型.
pos: 位置, 0.0f - 1.0f.
flag: 缓动标识, Ease_Flag_.
缓动_Expo, 突击曲线, 突然一下.
p: 位置, 0.0f - 1.0f.
flag: 缓动类型, Ease_Type_.
缓动_Linear, 线性.
p: 位置, 0.0f - 1.0f.
缓动_Quad, 二次方曲线.
p: 位置, 0.0f - 1.0f.
flag: 缓动类型, Ease_Type_.
缓动_Quart, 四次方曲线.
p: 位置, 0.0f - 1.0f.
flag: 缓动类型, Ease_Type_.
缓动_Quint, 五次方曲线.
p: 位置, 0.0f - 1.0f.
flag: 缓动类型, Ease_Type_.
缓动_Sine, 正弦曲线, 在末端变化.
p: 位置, 0.0f - 1.0f.
flag: 缓动类型, Ease_Type_.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.