Documentation
¶
Index ¶
- type FrameWindow
- func (fw *FrameWindow) AddPane(hPaneDest int, hPaneNew int, align int) bool
- func (fw *FrameWindow) GetLayoutAreaRect(pRect *xc.RECT) int
- func (w *FrameWindow) GetObjectByID(nID int) int
- func (w *FrameWindow) GetObjectByIDName(pName string) int
- func (w *FrameWindow) IsHWINDOW() bool
- func (fw *FrameWindow) LoadLayoutFile(aPaneList int, nPaneCount int, pFileName string) bool
- func (fw *FrameWindow) MergePane(hPaneDest int, hPaneNew int) bool
- func (w *FrameWindow) MessageBox(pText string, pCaption string, nFlags int) int
- func (w *FrameWindow) PostMessage(msg int, wParam int, lParam int) bool
- func (fw *FrameWindow) SaveLayoutToFile(pFileName string) bool
- func (w *FrameWindow) SendMessage(msg int, wParam int, lParam int) int
- func (w *FrameWindow) SetHWindow(hWindow int)
- func (fw *FrameWindow) SetPaneSplitBarColor(color int, alpha uint8) int
- func (fw *FrameWindow) SetTabBarHeight(nHeight int) int
- func (fw *FrameWindow) SetView(hEle int) int
- type ModalWindow
- func (m *ModalWindow) DoModal() int
- func (m *ModalWindow) EnableAutoClose(bEnable bool) int
- func (m *ModalWindow) EnableEscClose(bEnable bool) int
- func (m *ModalWindow) EndModal(nResult int) int
- func (w *ModalWindow) GetObjectByID(nID int) int
- func (w *ModalWindow) GetObjectByIDName(pName string) int
- func (w *ModalWindow) IsHWINDOW() bool
- func (w *ModalWindow) MessageBox(pText string, pCaption string, nFlags int) int
- func (w *ModalWindow) PostMessage(msg int, wParam int, lParam int) bool
- func (w *ModalWindow) SendMessage(msg int, wParam int, lParam int) int
- func (w *ModalWindow) SetHWindow(hWindow int)
- type Window
- func (w *Window) AddChild(hChild int) bool
- func (w *Window) AdjustLayout() int
- func (w *Window) AdjustLayoutEx(nFlags int) int
- func (w *Window) Center() int
- func (w *Window) CenterEx(width, height int) int
- func (w *Window) CloseWindow() int
- func (w *Window) CreateCaret(hEle, x, y, width, height int) int
- func (w *Window) DestroyCaret() int
- func (w *Window) DrawWindow(hDraw int) int
- func (w *Window) EnableAutoFocus(bEnable bool) int
- func (w *Window) EnableDragBorder(bEnable bool) int
- func (w *Window) EnableDragCaption(bEnable bool) int
- func (w *Window) EnableDragWindow(bEnable bool) int
- func (w *Window) EnableDrawBk(bEnable bool) int
- func (w *Window) EnableLayout(bEnable bool) int
- func (w *Window) EnableLayoutOverlayBorder(bEnable bool) int
- func (w *Window) EnableMaxWindow(bEnable bool) int
- func (w *Window) EnablemLimitWindowSize(bEnable bool) int
- func (w *Window) GetBkManager() int
- func (w *Window) GetBkManagerEx() int
- func (w *Window) GetBodyRect(pRect *xc.RECT) int
- func (w *Window) GetBorderSize(pBorder *xc.RECT) int
- func (w *Window) GetCaptureEle() int
- func (w *Window) GetCaretHELE() int
- func (w *Window) GetChild(nID int) int
- func (w *Window) GetChildByID(nID int) int
- func (w *Window) GetChildByIndex(index int) int
- func (w *Window) GetChildCount() int
- func (w *Window) GetClientRect(pRect *xc.RECT) int
- func (w *Window) GetCursor() int
- func (w *Window) GetDragBorderSize(pBorder *xc.RECT) int
- func (w *Window) GetDrawRect(pRcPaint *xc.RECT) int
- func (w *Window) GetFocusEle() int
- func (w *Window) GetHWND() int
- func (w *Window) GetID() int
- func (w *Window) GetLayoutRect(pRect *xc.RECT) int
- func (w *Window) GetName() string
- func (w *Window) GetObjectByID(nID int) int
- func (w *Window) GetObjectByIDName(pName string) int
- func (w *Window) GetRect(pRect *xc.RECT) int
- func (w *Window) GetShadowInfo(nSize *int, nDepth *uint8, nAngeleSize *int, bRightAngle *bool, color *int) int
- func (w *Window) GetStayEle() int
- func (w *Window) GetTextColor() int
- func (w *Window) GetTextColorEx() int
- func (w *Window) GetTransparentType() int
- func (w *Window) HitChildEle(pPt *xc.POINT) int
- func (w *Window) InsertChild(hChild int, index int) bool
- func (w *Window) IsEnableLayout() bool
- func (w *Window) IsHWINDOW() bool
- func (w *Window) IsMaxWindow() bool
- func (w *Window) KillTimer(nIDEvent int) int
- func (w *Window) KillXCTimer(nIDEvent int) int
- func (w *Window) MaxWindow(bMaximize bool) int
- func (w *Window) MessageBox(pText string, pCaption string, nFlags int) int
- func (w *Window) Move(x, y int) int
- func (w *Window) PostMessage(msg int, wParam int, lParam int) bool
- func (w *Window) Redraw(bImmediate bool) int
- func (w *Window) RedrawRect(pRect *xc.RECT, bImmediate bool) int
- func (w *Window) RegEventC(nEvent int, pFun interface{}) bool
- func (w *Window) RegEventC1(nEvent int, pFun interface{}) bool
- func (w *Window) RemoveEventC(nEvent int, pFun interface{}) bool
- func (w *Window) SendMessage(msg int, wParam int, lParam int) int
- func (w *Window) SetBkMagager(hBkInfoM int) int
- func (w *Window) SetBorderSize(left, top, right, bottom int) int
- func (w *Window) SetCaptureEle(hEle int) int
- func (w *Window) SetCaretColor(color int) int
- func (w *Window) SetCaretPos(x, y int) int
- func (w *Window) SetCaretPosEx(x, y, width, height int) int
- func (w *Window) SetCaretSize(width, height int) int
- func (w *Window) SetCursor(hCursor int) int
- func (w *Window) SetCursorSys(hCursor int) int
- func (w *Window) SetDragBorderSize(left, top, right, bottom int) int
- func (w *Window) SetFocusEle(hFocusEle int) bool
- func (w *Window) SetFont(hFontx int) int
- func (w *Window) SetHWindow(hWindow int)
- func (w *Window) SetID(nID int) int
- func (w *Window) SetMinimumSize(width, height int) int
- func (w *Window) SetName(pName string) int
- func (w *Window) SetPadding(left, top, right, bottom int) int
- func (w *Window) SetRect(pRect *xc.RECT) bool
- func (w *Window) SetShadowInfo(nSize int, nDepth uint8, nAngeleSize int, bRightAngle bool, color int) int
- func (w *Window) SetTextColor(color int, alpha uint8) int
- func (w *Window) SetTimer(nIDEvent, uElapse int) int
- func (w *Window) SetTop() int
- func (w *Window) SetTransparentAlpha(alpha uint8) int
- func (w *Window) SetTransparentColor(color int) int
- func (w *Window) SetTransparentType(nType int) int
- func (w *Window) SetXCTimer(nIDEvent, uElapse int) int
- func (w *Window) ShowCaret(bShow bool) int
- func (w *Window) ShowLayoutFrame(bEnable bool) int
- func (w *Window) ShowWindow(nCmdShow int) int
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type FrameWindow ¶
type FrameWindow struct {
// contains filtered or unexported fields
}
func NewFreamWindow ¶
func NewFreamWindow(x int, y int, cx int, cy int, pTitle string, hWndParent int, XCStyle int) *FrameWindow
框架窗口_创建, 返回GUI库窗口资源句柄 x: 窗口左上角x坐标. y: 窗口左上角y坐标. cx: 窗口宽度. cy: 窗口高度. pTitle: 窗口标题. hWndParent: 父窗口. XCStyle: GUI库窗口样式, Xc_Window_Style_
func NewFreamWindowEx ¶
func NewFreamWindowEx(dwExStyle int, lpClassName string, lpWindowName string, dwStyle int, x int, y int, cx int, cy int, hWndParent int, XCStyle int) *FrameWindow
框架窗口_创建扩展, 返回GUI库窗口资源句柄 dwExStyle: 窗口扩展样式. lpClassName: 窗口类名. lpWindowName: 窗口名. dwStyle: 窗口样式 x: 窗口左上角x坐标. y: 窗口左上角y坐标. cx: 窗口宽度. cy: 窗口高度. hWndParent: 父窗口. XCStyle: GUI库窗口样式, Xc_Window_Style_
func (*FrameWindow) AddPane ¶
func (fw *FrameWindow) AddPane(hPaneDest int, hPaneNew int, align int) bool
框架窗口_添加窗格, 添加窗格到框架窗口 hPaneDest: 目标窗格. hPaneNew: 当前窗格. align: 对齐方式, Pane_Align_
func (*FrameWindow) GetLayoutAreaRect ¶
func (fw *FrameWindow) GetLayoutAreaRect(pRect *xc.RECT) int
框架窗口_取布局区域坐标, 用来布局窗格的区域坐标, 不包含码头 pRect: 返回坐标.
func (*FrameWindow) GetObjectByID ¶ added in v0.0.3
炫彩_取对象从ID, 通过ID获取对象句柄, 不包括窗口对象 nID: ID值.
func (*FrameWindow) GetObjectByIDName ¶ added in v0.0.3
炫彩_取对象从ID名称, 通过ID名称获取对象句柄 pName: ID名称.
func (*FrameWindow) IsHWINDOW ¶ added in v0.0.3
func (w *FrameWindow) IsHWINDOW() bool
炫彩_判断窗口, 判断是否为窗口句柄
func (*FrameWindow) LoadLayoutFile ¶
func (fw *FrameWindow) LoadLayoutFile(aPaneList int, nPaneCount int, pFileName string) bool
框架窗口_加载布局信息文件, 加载布局信息文件 aPaneList: 窗格句柄数组. nPaneCount: 窗格数量. pFileName: 文件名,如果文件名为空,将使用默认文件名frameWnd_layout.xml.
func (*FrameWindow) MergePane ¶
func (fw *FrameWindow) MergePane(hPaneDest int, hPaneNew int) bool
框架窗口_合并窗格 hPaneDest: 目标窗格. hPaneNew: 当前窗格.
func (*FrameWindow) MessageBox ¶ added in v0.0.3
炫彩_消息框 pText: 内容文本 pCaption: 标题 nFlags: 标识, MessageBox_Flag_
func (*FrameWindow) PostMessage ¶ added in v0.0.3
炫彩_投递窗口消息 msg: wParam: lParam:
func (*FrameWindow) SaveLayoutToFile ¶
func (fw *FrameWindow) SaveLayoutToFile(pFileName string) bool
框架窗口_保存布局到文件, 保存布局信息到文件 pFileName: 文件名,如果文件名为空,将使用默认文件名frameWnd_layout.xml.
func (*FrameWindow) SendMessage ¶ added in v0.0.3
炫彩_发送窗口消息 msg: wParam: lParam:
func (*FrameWindow) SetHWindow ¶ added in v0.0.3
func (w *FrameWindow) SetHWindow(hWindow int)
给本类的HWindow和HWND赋值
func (*FrameWindow) SetPaneSplitBarColor ¶
func (fw *FrameWindow) SetPaneSplitBarColor(color int, alpha uint8) int
框架窗口_置窗格分隔条颜色 color: RGB颜色值 alpha: 透明度
func (*FrameWindow) SetTabBarHeight ¶
func (fw *FrameWindow) SetTabBarHeight(nHeight int) int
框架窗口_置TabBar条高度, 设置窗格组TabBar高度 nHeight: 高度
func (*FrameWindow) SetView ¶
func (fw *FrameWindow) SetView(hEle int) int
框架窗口_置视图, 设置窗格组TabBar高度 hEle: 元素句柄.
type ModalWindow ¶
type ModalWindow struct {
Window
}
func NewModalWindow ¶
func NewModalWindow(nWidth int, nHeight int, pTitle string, hWndParent int, XCStyle int) *ModalWindow
模态窗口_创建, 创建模态窗口, 然后调用DoModal()显示; 当模态窗口关闭时, 会自动销毁模态窗口资源句柄 nWidth: 宽度. nHeight: 高度. pTitle: 窗口标题内容. hWndParent: 父窗口句柄. XCStyle: 炫彩窗口样式, Xc_Window_Style_
func NewModalWindowEx ¶
func NewModalWindowEx(dwExStyle int, lpClassName string, lpWindowName string, dwStyle int, x int, y int, cx int, cy int, hWndParent int, XCStyle int) *ModalWindow
模态窗口_创建扩展, 创建模态窗口,增强功能 dwExStyle: 窗口扩展样式. lpClassName: 窗口类名. lpWindowName: 窗口名. dwStyle: 窗口样式. x: 窗口左上角x坐标. y: 窗口左上角y坐标. cx: 窗口宽度. cy: 窗口高度. hWndParent: 父窗口. XCStyle: GUI库窗口样式, Xc_Window_Style_
func (*ModalWindow) DoModal ¶
func (m *ModalWindow) DoModal() int
模态窗口_启动, 启动显示模态窗口, 当窗口关闭时返回: MessageBox_Flag_Ok: 点击确定按钮退出, MessageBox_Flag_Cancel: 点击取消按钮退出, MessageBox_Flag_Other: 其他方式退出
func (*ModalWindow) EnableAutoClose ¶
func (m *ModalWindow) EnableAutoClose(bEnable bool) int
模态窗口_启用自动关闭, 是否自动关闭窗口, 当窗口失去焦点时 bEnable: 开启开关.
func (*ModalWindow) EnableEscClose ¶
func (m *ModalWindow) EnableEscClose(bEnable bool) int
模态窗口_启用ESC关闭, 当用户按ESC键时自动关闭模态窗口 bEnable: 是否启用
func (*ModalWindow) EndModal ¶
func (m *ModalWindow) EndModal(nResult int) int
模态窗口_结束, 结束模态窗口, 返回: MessageBox_Flag_Ok: 点击确定按钮退出, MessageBox_Flag_Cancel: 点击取消按钮退出, MessageBox_Flag_Other: 其他方式退出 nResult: XModalWnd_DoModal()返回值.
func (*ModalWindow) GetObjectByID ¶ added in v0.0.3
炫彩_取对象从ID, 通过ID获取对象句柄, 不包括窗口对象 nID: ID值.
func (*ModalWindow) GetObjectByIDName ¶ added in v0.0.3
炫彩_取对象从ID名称, 通过ID名称获取对象句柄 pName: ID名称.
func (*ModalWindow) IsHWINDOW ¶ added in v0.0.3
func (w *ModalWindow) IsHWINDOW() bool
炫彩_判断窗口, 判断是否为窗口句柄
func (*ModalWindow) MessageBox ¶ added in v0.0.3
炫彩_消息框 pText: 内容文本 pCaption: 标题 nFlags: 标识, MessageBox_Flag_
func (*ModalWindow) PostMessage ¶ added in v0.0.3
炫彩_投递窗口消息 msg: wParam: lParam:
func (*ModalWindow) SendMessage ¶ added in v0.0.3
炫彩_发送窗口消息 msg: wParam: lParam:
func (*ModalWindow) SetHWindow ¶ added in v0.0.3
func (w *ModalWindow) SetHWindow(hWindow int)
给本类的HWindow和HWND赋值
type Window ¶
type Window struct {
// contains filtered or unexported fields
}
func NewWindow ¶
窗口_创建, 返回: GUI库窗口资源句柄 x: 窗口左上角x坐标. y: 窗口左上角y坐标. cx: 窗口宽度. cy: 窗口高度. pTitle: 窗口标题. hWndParent: 父窗口. XCStyle: GUI库窗口样式, Xc_Window_Style_
func NewWindowEx ¶
func NewWindowEx(dwExStyle int, lpClassName string, lpWindowName string, dwStyle int, x int, y int, cx int, cy int, hWndParent int, XCStyle int) *Window
窗口_创建扩展, 返回: GUI库窗口资源句柄 dwExStyle: 窗口扩展样式. lpClassName: 窗口类名. lpWindowName: 窗口名. dwStyle: 窗口样式 x: 窗口左上角x坐标. y: 窗口左上角y坐标. cx: 窗口宽度. cy: 窗口高度. hWndParent: 父窗口. XCStyle: GUI库窗口样式, Xc_Window_Style_
func (*Window) AdjustLayoutEx ¶
窗口_调整布局扩展 nFlags: 调整标识, AdjustLayout_
func (*Window) CreateCaret ¶
窗口_创建插入符 hEle: 元素句柄. x: x坐标. y: y坐标. width: 宽度. height: 高度.
func (*Window) EnableAutoFocus ¶
窗口_启用自动焦点 bEnable: 是否启用.
func (*Window) EnableDragBorder ¶
窗口_启用拖动边框 bEnable: 是否启用.
func (*Window) EnableDragCaption ¶
窗口_启用拖动标题栏 bEnable: 是否启用.
func (*Window) EnableDragWindow ¶
窗口_启用拖动窗口 bEnable: 是否启用.
func (*Window) EnableDrawBk ¶
窗口_启用绘制背景 bEnable: 是否启用.
func (*Window) EnableLayout ¶
窗口_启用布局 bEnable: 是否启用.
func (*Window) EnableLayoutOverlayBorder ¶
窗口_启用布局覆盖边框 bEnable: 是否启用
func (*Window) EnableMaxWindow ¶
窗口_启用允许最大化 bEnable: 是否启用.
func (*Window) EnablemLimitWindowSize ¶
窗口_启用限制窗口大小 bEnable: 是否启用
func (*Window) GetChildByID ¶
窗口_取子对象从ID nID: 元素ID, ID必须大于0.
func (*Window) GetChildByIndex ¶
窗口_取子对象从索引 index: 元素索引.
func (*Window) GetClientRect ¶
窗口_取客户区坐标 pRect: 坐标.
func (*Window) GetDragBorderSize ¶
窗口_取拖动边框大小 pSize: 拖动边框大小.
func (*Window) GetDrawRect ¶
窗口_取绘制矩形 pRcPaint: 重绘区域坐标.
func (*Window) GetLayoutRect ¶
窗口_取布局坐标 pRect: 接收返回坐标
func (*Window) GetObjectByID ¶ added in v0.0.3
炫彩_取对象从ID, 通过ID获取对象句柄, 不包括窗口对象 nID: ID值.
func (*Window) GetObjectByIDName ¶ added in v0.0.3
炫彩_取对象从ID名称, 通过ID名称获取对象句柄 pName: ID名称.
func (*Window) GetShadowInfo ¶
func (w *Window) GetShadowInfo(nSize *int, nDepth *uint8, nAngeleSize *int, bRightAngle *bool, color *int) int
窗口_取阴影信息 pnSize: 阴影大小. pnDepth: 阴影深度. pnAngeleSize: 圆角阴影内收大小 . pbRightAngle: 是否强制直角. pColor: 阴影颜色.
func (*Window) InsertChild ¶
窗口_插入子对象 hChild: 要插入的对象句柄. index: 插入位置索引.
func (*Window) KillXCTimer ¶
窗口_关闭炫彩定时器 nIDEvent: 定时器ID.
func (*Window) MessageBox ¶ added in v0.0.3
炫彩_消息框 pText: 内容文本 pCaption: 标题 nFlags: 标识, MessageBox_Flag_
func (*Window) PostMessage ¶ added in v0.0.3
炫彩_投递窗口消息 msg: wParam: lParam:
func (*Window) RedrawRect ¶
窗口_重绘指定区域 pRect: 需要重绘的区域坐标. bImmediate: TRUE立即重绘, FALSE放入消息队列延迟重绘.
func (*Window) RegEventC1 ¶
窗口_注册事件C1 nEvent: 事件类型. pFun: 事件函数.
func (*Window) RemoveEventC ¶
窗口_移除事件C nEvent: 事件类型. pFun: 事件函数.
func (*Window) SendMessage ¶ added in v0.0.3
炫彩_发送窗口消息 msg: wParam: lParam:
func (*Window) SetBkMagager ¶
窗口_置背景管理器 hBkInfoM: 背景管理器
func (*Window) SetBorderSize ¶
窗口_置边大小 left: 窗口左边大小. top: 窗口上边大小. right: 窗口右边大小. bottom: 窗口底部大小.
func (*Window) SetCaretPosEx ¶
窗口_置插入符位置扩展 x: x坐标. y: y坐标. width: 宽度. height: 高度.
func (*Window) SetCaretSize ¶
窗口_置插入符大小 width: 宽度. height: 高度.
func (*Window) SetCursorSys ¶
窗口_置系统光标 hCursor: 光标句柄.
func (*Window) SetDragBorderSize ¶
窗口_置拖动边框大小 left: 窗口左边大小. top: 窗口上边大小. right: 窗口右边大小. bottom: 窗口底边大小.
func (*Window) SetFocusEle ¶
窗口_置焦点 hFocusEle: 将获得焦点的元素.
func (*Window) SetHWindow ¶ added in v0.0.3
func (w *Window) SetHWindow(hWindow int)
给本类的HWindow和HWND赋值
func (*Window) SetMinimumSize ¶
窗口_置最小大小 width: 最小宽度. height: 最小高度.
func (*Window) SetPadding ¶
窗口_置布局内填充大小 left: 左边大小. top: 上边大小. right: 右边大小. bottom: 下边大小.
func (*Window) SetShadowInfo ¶
func (w *Window) SetShadowInfo(nSize int, nDepth uint8, nAngeleSize int, bRightAngle bool, color int) int
窗口_置阴影信息 nSize: 阴影大小 nDepth: 阴影深度, 0-255. nAngeleSize: 圆角阴影内收大小. bRightAngle: 是否强制直角. color: 阴影颜色.
func (*Window) SetTextColor ¶
窗口_置文本颜色 color: RGB颜色值. alpha: 透明度.
func (*Window) SetTransparentAlpha ¶
窗口_置透明度 alpha: 窗口透明度, 范围0-255之间, 0透明, 255不透明.
func (*Window) SetTransparentColor ¶
窗口_置透明色 color: 窗口透明色.
func (*Window) SetTransparentType ¶
窗口_置透明类型 nType: 窗口透明类型.
func (*Window) SetXCTimer ¶
窗口_置炫彩定时器 nIDEvent: 定时器ID. uElapse: 间隔值, 单位毫秒.
func (*Window) ShowLayoutFrame ¶
窗口_显示布局边界 bEnable: 是否启用.