package
Version:
v1.0.5
Opens a new window with list of versions in this module.
Published: Oct 15, 2021
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 2
Opens a new window with list of known importers.
Documentation
¶
-
func Back(p float32, flag int) int
-
func Bounce(p float32, flag int) int
-
func Circ(p float32, flag int) int
-
func Cubic(p float32, flag int) int
-
func Elastic(p float32, flag int) int
-
func Expo(p float32, flag int) int
-
func Linear(p float32) int
-
func Quad(p float32, flag int) int
-
func Quart(p float32, flag int) int
-
func Quint(p float32, flag int) int
-
func Sine(p float32, flag int) int
缓动_Back
p: 位置, 0.0f - 1.0f
flag: 缓动方式, Ease_
缓动_Bounce
p: 位置, 0.0f - 1.0f
flag: 缓动方式, Ease_
缓动_Circ
p: 位置, 0.0f - 1.0f
flag: 缓动方式, Ease_
缓动_Cubic
p: 位置, 0.0f - 1.0f
flag: 缓动方式, Ease_
缓动_Elastic
p: 位置, 0.0f - 1.0f
flag: 缓动方式, Ease_
缓动_Expo
p: 位置, 0.0f - 1.0f
flag: 缓动方式, Ease_
缓动_Linear
p: 位置, 0.0f - 1.0f
缓动_Quad
p: 位置, 0.0f - 1.0f
flag: 缓动方式, Ease_
缓动_Quart
p: 位置, 0.0f - 1.0f
flag: 缓动方式, Ease_
缓动_Quint
p: 位置, 0.0f - 1.0f
flag: 缓动方式, Ease_
缓动_Sine
p: 位置, 0.0f - 1.0f
flag: 缓动方式, Ease_
Source Files
¶
Click to show internal directories.
Click to hide internal directories.